class dpi_pcap_merger (
  String                $app_bin   = '/usr/local/bin/dpi-pcap-merger',
  Hash[String,Hash]     $files     = {},
  Hash[String,Hash]     $packages  = {},
  Hash[String[1], Hash] $instances = {},
) inherits dpi_pcap_merger::params {

  create_resources(package, $packages)

  $file_defaults = {
    owner => 0,
    group => 0,
    mode  => '0755',
  }

  create_resources(file, $files, $file_defaults)

  # Удаление файлов и выключение юнитов которые больше не нужны
  if $facts['dpi_pcap_merge_names'] != [] {
    $facts['dpi_pcap_merge_names'].each |String $dumper_service| {
      if ! ($dumper_service in $instances.keys()) {
        $timestamp = Timestamp.new().strftime('%Y-%m-%d-%H:%M:%S')
        notify {"${dumper_service}":}
        systemd::unit_file { "dpi_pcap_merger-${dumper_service}.service":
          ensure  => 'absent',
          active  => false,
          enable  => false,
        }
        ~> exec { "delete_log_dpi_pcap_merger-${dumper_service}.service": # file_line module doesnt have attribute refreshonly
          command => "echo '${timestamp}: prune orphaned: dpi_pcap_merger-${dumper_service}.service' >> /var/log/dpi_pcap_merger/prune-systemd-units.log",
          refreshonly => true,
        } 
        -> file { "/var/log/dpi_pcap_merger/dpi_pcap_merger-${dumper_service}.service.log":
          ensure => 'absent',
        }
        -> exec { "reset-failed_${dumper_service}":
          command => "systemctl reset-failed dpi_pcap_merger-${dumper_service}.service",
        }
      }
    }
  }
 
  # Создание юнитов
  $instances.each | String $key, Hash $values | {
    $timestamp = Timestamp.new().strftime('%Y-%m-%d-%H:%M:%S')
    systemd::unit_file { "dpi_pcap_merger-${key}.service":
      ensure  => 'present',
      owner   => 'root',
      group   => 'root',
      mode    => '0644',
      enable => $values['enable'],
      active => $values['active'],
      content => epp(
        "${module_name}/dpi_pcap_merger@.service.epp",
        {
          args    => $values['args'],
          app_bin => $app_bin,
          name    => $key,
        }
      ),
    }
    ~> exec { "create_log_dpi_pcap_merger-${key}.service": # file_line module doesnt have attribute refreshonly
      command => "echo '${timestamp}: create new: dpi_pcap_merger-${key}.service' >> /var/log/dpi_pcap_merger/prune-systemd-units.log",
      refreshonly => true,
    }
    -> service { "dpi_pcap_merger-${key}":
      ensure => $values['enable'],
      enable => $values['active'],
      hasrestart => true,
      hasstatus  => true,
      provider   => systemd,
    }
  }
}

