# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`grafana`](#grafana): Installs and configures Grafana.
* [`grafana::validator`](#grafana--validator): Manage grafana_conn_validator resource

#### Private Classes

* `grafana::config`: Manage grafana configuration
* `grafana::install`: Manage grafana installation
* `grafana::service`: Manage grafana service

### Resource types

* [`grafana_conn_validator`](#grafana_conn_validator): Verify connectivity to the Grafana API
* [`grafana_dashboard`](#grafana_dashboard): Manage dashboards in Grafana
* [`grafana_dashboard_permission`](#grafana_dashboard_permission): Manage dashboard permissions in Grafana
* [`grafana_datasource`](#grafana_datasource): Manage datasources in Grafana
* [`grafana_folder`](#grafana_folder): Manage folders in Grafana
* [`grafana_ldap_config`](#grafana_ldap_config): Manage Grafana LDAP configuration
* [`grafana_ldap_group_mapping`](#grafana_ldap_group_mapping): Map an LDAP group to a Grafana role.
* [`grafana_ldap_server`](#grafana_ldap_server): Manage Grafana LDAP servers for LDAP authentication.
* [`grafana_membership`](#grafana_membership): Manage resource memberships in Grafana
* [`grafana_notification`](#grafana_notification): Manage notification in Grafana
* [`grafana_organization`](#grafana_organization): Manage organizations in Grafana
* [`grafana_plugin`](#grafana_plugin): manages grafana plugins
* [`grafana_team`](#grafana_team): Manage teams in Grafana
* [`grafana_user`](#grafana_user): Manage users in Grafana

### Functions

* [`grafana::deep_find_and_remove`](#grafana--deep_find_and_remove): == Function: deep_find_and_remove  This function takes a hash as input, along with a string (key). Additionally, the optional removekey (defa
* [`grafana::get_sub_paths`](#grafana--get_sub_paths): == Function get_sub_paths  This function receives an input path as an input parameter, and returns an array of the subpaths in the input, exc

### Tasks

* [`change_grafana_admin_password`](#change_grafana_admin_password): Change the Grafana admin user's password

## Classes

### <a name="grafana"></a>`grafana`

Installs and configures Grafana.

#### Examples

##### Using the Class

```puppet
class { '::grafana':
  install_method  => 'docker',
}
```

#### Parameters

The following parameters are available in the `grafana` class:

* [`archive_source`](#-grafana--archive_source)
* [`cfg_location`](#-grafana--cfg_location)
* [`ldap_cfg`](#-grafana--ldap_cfg)
* [`container_cfg`](#-grafana--container_cfg)
* [`container_params`](#-grafana--container_params)
* [`data_dir`](#-grafana--data_dir)
* [`install_dir`](#-grafana--install_dir)
* [`install_method`](#-grafana--install_method)
* [`manage_package_repo`](#-grafana--manage_package_repo)
* [`package_name`](#-grafana--package_name)
* [`package_source`](#-grafana--package_source)
* [`service_name`](#-grafana--service_name)
* [`version`](#-grafana--version)
* [`repo_name`](#-grafana--repo_name)
* [`repo_gpg_key_url`](#-grafana--repo_gpg_key_url)
* [`repo_key_id`](#-grafana--repo_key_id)
* [`repo_release`](#-grafana--repo_release)
* [`repo_url`](#-grafana--repo_url)
* [`plugins`](#-grafana--plugins)
* [`provisioning_dashboards`](#-grafana--provisioning_dashboards)
* [`provisioning_datasources`](#-grafana--provisioning_datasources)
* [`provisioning_dashboards_file`](#-grafana--provisioning_dashboards_file)
* [`provisioning_datasources_file`](#-grafana--provisioning_datasources_file)
* [`create_subdirs_provisioning`](#-grafana--create_subdirs_provisioning)
* [`sysconfig_location`](#-grafana--sysconfig_location)
* [`sysconfig`](#-grafana--sysconfig)
* [`ldap_servers`](#-grafana--ldap_servers)
* [`ldap_group_mappings`](#-grafana--ldap_group_mappings)
* [`toml_manage_package`](#-grafana--toml_manage_package)
* [`toml_package_name`](#-grafana--toml_package_name)
* [`toml_package_ensure`](#-grafana--toml_package_ensure)
* [`toml_package_provider`](#-grafana--toml_package_provider)
* [`docker_image`](#-grafana--docker_image)
* [`docker_ports`](#-grafana--docker_ports)
* [`rpm_iteration`](#-grafana--rpm_iteration)
* [`cfg`](#-grafana--cfg)

##### <a name="-grafana--archive_source"></a>`archive_source`

Data type: `Optional[String]`

Download location of tarball to be used with the 'archive' install method.

Default value: `undef`

##### <a name="-grafana--cfg_location"></a>`cfg_location`

Data type: `String`

Location of the configuration file.

##### <a name="-grafana--ldap_cfg"></a>`ldap_cfg`

Data type: `Optional[Variant[Hash,Array[Hash],Sensitive[Hash],Sensitive[Array[Hash]]]]`



Default value: `undef`

##### <a name="-grafana--container_cfg"></a>`container_cfg`

Data type: `Boolean`

Determines whether a configuration file should be generated when using the 'docker' install method.
If true, use the `cfg` and `cfg_location` parameters to control creation of the file.

Default value: `false`

##### <a name="-grafana--container_params"></a>`container_params`

Data type: `Hash`

Parameters to use when creating the Docker container. For use with the 'docker' install method.
Refer to documentation of the `docker::run` resource in the `garethr-docker` module for details of available parameters.

Default value: `{}`

##### <a name="-grafana--data_dir"></a>`data_dir`

Data type: `String`

The directory Grafana will use for storing its data.

Default value: `'/var/lib/grafana'`

##### <a name="-grafana--install_dir"></a>`install_dir`

Data type: `String`

Installation directory to be used with the 'archive' install method.

Default value: `'/usr/share/grafana'`

##### <a name="-grafana--install_method"></a>`install_method`

Data type: `Enum['archive', 'docker', 'package', 'repo']`

Set to 'archive' to install Grafana using the tar archive.
Set to 'docker' to install Grafana using the official Docker container.
Set to 'package' to install Grafana using .deb or .rpm packages.
Set to 'repo' to install Grafana using an apt or yum repository.

##### <a name="-grafana--manage_package_repo"></a>`manage_package_repo`

Data type: `Boolean`

If true this will setup the official grafana repositories on your host.

##### <a name="-grafana--package_name"></a>`package_name`

Data type: `String`

The name of the package managed with the 'package' install method.

##### <a name="-grafana--package_source"></a>`package_source`

Data type: `Optional[String]`

Download location of package to be used with the 'package' install method.

Default value: `undef`

##### <a name="-grafana--service_name"></a>`service_name`

Data type: `String`

The name of the service managed with the 'archive' and 'package' install methods.

##### <a name="-grafana--version"></a>`version`

Data type: `String`

The version of Grafana to install and manage.

Default value: `'installed'`

##### <a name="-grafana--repo_name"></a>`repo_name`

Data type: `Enum['stable', 'beta', 'custom']`

When using 'repo' install_method, the repo to look for packages in.
Set to 'stable' to install only stable versions
Set to 'beta' to install beta versions
Set to 'custom' to install from custom repo. Use full URL

Default value: `'stable'`

##### <a name="-grafana--repo_gpg_key_url"></a>`repo_gpg_key_url`

Data type: `Stdlib::HTTPUrl`

When using 'repo' install_method, the repo_gpg_key_url to look for the gpg signing key of the repo.

Default value: `'https://packages.grafana.com/gpg.key'`

##### <a name="-grafana--repo_key_id"></a>`repo_key_id`

Data type: `String[1]`

When using 'repo' install_method, the repo_key_id of the repo_gpg_key_url key on Debian based systems.

Default value: `'B53AE77BADB630A683046005963FA27710458545'`

##### <a name="-grafana--repo_release"></a>`repo_release`

Data type: `Optional[String[1]]`

Optional value, needed on Debian based systems.
If repo name is set to custom, used to identify the release of the repo. No default value.

Default value: `undef`

##### <a name="-grafana--repo_url"></a>`repo_url`

Data type: `Optional[Stdlib::HTTPUrl]`

When using 'repo' install_method, the repo_url to look for packages in.
Set to a custom string value to install from a custom repo.

##### <a name="-grafana--plugins"></a>`plugins`

Data type: `Hash`

Plugins to be passed to `create_resources`, wraps around the
`grafana_plugin` resource.

Default value: `{}`

##### <a name="-grafana--provisioning_dashboards"></a>`provisioning_dashboards`

Data type: `Hash`

Dashboards to provision into grafana. grafana > v5.0.0
required. Will be converted into YAML and used by grafana to
provision dashboards.

Default value: `{}`

##### <a name="-grafana--provisioning_datasources"></a>`provisioning_datasources`

Data type: `Hash`

Datasources to provision into grafana, grafana > v5.0.0
required. Will be converted into YAML and used by granfana to
configure datasources.

Default value: `{}`

##### <a name="-grafana--provisioning_dashboards_file"></a>`provisioning_dashboards_file`

Data type: `String`

Fully qualified path to place the provisioning file
for dashboards, only used if provisioning_dashboards is specified.

Default value: `'/etc/grafana/provisioning/dashboards/puppetprovisioned.yaml'`

##### <a name="-grafana--provisioning_datasources_file"></a>`provisioning_datasources_file`

Data type: `String`

Fully qualified path to place the provisioning file
for datasources, only used if provisioning_datasources is specified.

Default value: `'/etc/grafana/provisioning/datasources/puppetprovisioned.yaml'`

##### <a name="-grafana--create_subdirs_provisioning"></a>`create_subdirs_provisioning`

Data type: `Boolean`

If true puppet will create any
subdirectories in the given path when provisioning dashboards.

Default value: `false`

##### <a name="-grafana--sysconfig_location"></a>`sysconfig_location`

Data type: `Optional[String]`

Location of the sysconfig file for the environment of the grafana-server service.
This is only used when the install_method is 'package' or 'repo'.

##### <a name="-grafana--sysconfig"></a>`sysconfig`

Data type: `Optional[Hash]`

Environment variables for the grafana-server service

Example:
  sysconfig => { 'http_proxy' => 'http://proxy.example.com/' }

Default value: `undef`

##### <a name="-grafana--ldap_servers"></a>`ldap_servers`

Data type: `Hash[String[1], Hash]`

Servers to be passed to `create_resources`, wraps around the
`grafana_ldap_server` resource.

Default value: `{}`

##### <a name="-grafana--ldap_group_mappings"></a>`ldap_group_mappings`

Data type: `Hash[String[1], Hash]`

ldap_group_mappings
Mappings to be passed to `create_resources`, wraps around the
`grafana_ldap_group_mapping` resource.

Default value: `{}`

##### <a name="-grafana--toml_manage_package"></a>`toml_manage_package`

Data type: `Boolean`

ruby-toml is required to generate the TOML-based LDAP config for Grafana.
Set to false if you manage package- or gem-install
somewhere else.

Default value: `true`

##### <a name="-grafana--toml_package_name"></a>`toml_package_name`

Data type: `String[1]`

Name of the software-package providing the TOML parser library.

Default value: `'ruby-toml'`

##### <a name="-grafana--toml_package_ensure"></a>`toml_package_ensure`

Data type: `String[1]`

Ensure the package-resource - e.g. installed, absent, etc.
https://puppet.com/docs/puppet/latest/types/package.html#package-attribute-ensure

Default value: `'present'`

##### <a name="-grafana--toml_package_provider"></a>`toml_package_provider`

Data type: `Optional[String[1]]`

The package-provider used to install the TOML parser library.

Default value: `undef`

##### <a name="-grafana--docker_image"></a>`docker_image`

Data type: `String`

name of the docker image that provides grafana

Default value: `'grafana/grafana'`

##### <a name="-grafana--docker_ports"></a>`docker_ports`

Data type: `String`

ports docker should expose

Default value: `'3000:3000'`

##### <a name="-grafana--rpm_iteration"></a>`rpm_iteration`

Data type: `String`

explicit Iteration / epoch for the rpm

Default value: `'1'`

##### <a name="-grafana--cfg"></a>`cfg`

Data type: `Variant[Hash,Sensitive[Hash]]`

The whole grafana configuration

Default value: `{}`

### <a name="grafana--validator"></a>`grafana::validator`

Manage grafana_conn_validator resource

#### Parameters

The following parameters are available in the `grafana::validator` class:

* [`grafana_url`](#-grafana--validator--grafana_url)
* [`grafana_api_path`](#-grafana--validator--grafana_api_path)

##### <a name="-grafana--validator--grafana_url"></a>`grafana_url`

Data type: `Stdlib::HTTPUrl`

Grafana URL.

Default value: `'http://localhost:3000'`

##### <a name="-grafana--validator--grafana_api_path"></a>`grafana_api_path`

Data type: `Stdlib::Absolutepath`

API path to validate with.

Default value: `'/api/health'`

## Resource types

### <a name="grafana_conn_validator"></a>`grafana_conn_validator`

Verify connectivity to the Grafana API

#### Properties

The following properties are available in the `grafana_conn_validator` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `grafana_conn_validator` type.

* [`grafana_api_path`](#-grafana_conn_validator--grafana_api_path)
* [`grafana_url`](#-grafana_conn_validator--grafana_url)
* [`name`](#-grafana_conn_validator--name)
* [`provider`](#-grafana_conn_validator--provider)
* [`timeout`](#-grafana_conn_validator--timeout)

##### <a name="-grafana_conn_validator--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api/health`

##### <a name="-grafana_conn_validator--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `http://localhost:3000`

##### <a name="-grafana_conn_validator--name"></a>`name`

namevar

Arbitrary name of this resource

##### <a name="-grafana_conn_validator--provider"></a>`provider`

The specific backend to use for this `grafana_conn_validator` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-grafana_conn_validator--timeout"></a>`timeout`

How long to wait for the API to be available

Default value: `20`

### <a name="grafana_dashboard"></a>`grafana_dashboard`

Manage dashboards in Grafana

#### Properties

The following properties are available in the `grafana_dashboard` type.

##### `content`

The JSON representation of the dashboard.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `grafana_dashboard` type.

* [`folder`](#-grafana_dashboard--folder)
* [`grafana_api_path`](#-grafana_dashboard--grafana_api_path)
* [`grafana_password`](#-grafana_dashboard--grafana_password)
* [`grafana_url`](#-grafana_dashboard--grafana_url)
* [`grafana_user`](#-grafana_dashboard--grafana_user)
* [`organization`](#-grafana_dashboard--organization)
* [`provider`](#-grafana_dashboard--provider)
* [`title`](#-grafana_dashboard--title)

##### <a name="-grafana_dashboard--folder"></a>`folder`

The folder to place the dashboard in (optional)

##### <a name="-grafana_dashboard--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_dashboard--grafana_password"></a>`grafana_password`

The password for the Grafana server (optional)

##### <a name="-grafana_dashboard--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_dashboard--grafana_user"></a>`grafana_user`

The username for the Grafana server (optional)

##### <a name="-grafana_dashboard--organization"></a>`organization`

The organization name to create the datasource on

Default value: `1`

##### <a name="-grafana_dashboard--provider"></a>`provider`

The specific backend to use for this `grafana_dashboard` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-grafana_dashboard--title"></a>`title`

The title of the dashboard.

### <a name="grafana_dashboard_permission"></a>`grafana_dashboard_permission`

Manage dashboard permissions in Grafana

#### Properties

The following properties are available in the `grafana_dashboard_permission` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `permission`

Valid values: `Admin`, `Edit`, `View`

The role to apply

#### Parameters

The following parameters are available in the `grafana_dashboard_permission` type.

* [`dashboard`](#-grafana_dashboard_permission--dashboard)
* [`grafana_api_path`](#-grafana_dashboard_permission--grafana_api_path)
* [`grafana_password`](#-grafana_dashboard_permission--grafana_password)
* [`grafana_url`](#-grafana_dashboard_permission--grafana_url)
* [`grafana_user`](#-grafana_dashboard_permission--grafana_user)
* [`name`](#-grafana_dashboard_permission--name)
* [`organization`](#-grafana_dashboard_permission--organization)
* [`provider`](#-grafana_dashboard_permission--provider)
* [`team`](#-grafana_dashboard_permission--team)
* [`user`](#-grafana_dashboard_permission--user)

##### <a name="-grafana_dashboard_permission--dashboard"></a>`dashboard`

Dashboard to modify permissions for

##### <a name="-grafana_dashboard_permission--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_dashboard_permission--grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="-grafana_dashboard_permission--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_dashboard_permission--grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="-grafana_dashboard_permission--name"></a>`name`

namevar

The name of the permission.

##### <a name="-grafana_dashboard_permission--organization"></a>`organization`

The name of the organization to add permission for

Default value: `Main Org.`

##### <a name="-grafana_dashboard_permission--provider"></a>`provider`

The specific backend to use for this `grafana_dashboard_permission` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="-grafana_dashboard_permission--team"></a>`team`

Team to add the permission for

##### <a name="-grafana_dashboard_permission--user"></a>`user`

User to add the permission for

### <a name="grafana_datasource"></a>`grafana_datasource`

Manage datasources in Grafana

#### Properties

The following properties are available in the `grafana_datasource` type.

##### `access_mode`

Valid values: `direct`, `proxy`

Whether the datasource is accessed directly or not by the clients

##### `basic_auth`

Valid values: `true`, `false`

Whether basic auth is enabled or not

##### `basic_auth_password`

The password for basic auth if enabled

##### `basic_auth_user`

The username for basic auth if enabled

##### `database`

The name of the database (optional)

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `is_default`

Valid values: `true`, `false`

Whether the datasource is the default one

##### `json_data`

Additional JSON data to configure the datasource (optional)

##### `password`

The password for the datasource (optional)

##### `secure_json_data`

Additional secure JSON data to configure the datasource (optional)

##### `type`

The datasource type

##### `uid`

An optional unique identifier for the datasource. Supported by grafana 7.3 onwards. If you do not specify this parameter, grafana will assign a uid for you

##### `url`

The URL/Endpoint of the datasource

##### `user`

The username for the datasource (optional)

##### `with_credentials`

Valid values: `true`, `false`

Whether credentials such as cookies or auth headers should be sent with cross-site requests

#### Parameters

The following parameters are available in the `grafana_datasource` type.

* [`grafana_api_path`](#-grafana_datasource--grafana_api_path)
* [`grafana_password`](#-grafana_datasource--grafana_password)
* [`grafana_url`](#-grafana_datasource--grafana_url)
* [`grafana_user`](#-grafana_datasource--grafana_user)
* [`name`](#-grafana_datasource--name)
* [`organization`](#-grafana_datasource--organization)
* [`provider`](#-grafana_datasource--provider)

##### <a name="-grafana_datasource--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_datasource--grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="-grafana_datasource--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_datasource--grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="-grafana_datasource--name"></a>`name`

namevar

The name of the datasource.

##### <a name="-grafana_datasource--organization"></a>`organization`

The organization name to create the datasource on

Default value: `1`

##### <a name="-grafana_datasource--provider"></a>`provider`

The specific backend to use for this `grafana_datasource` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="grafana_folder"></a>`grafana_folder`

Manage folders in Grafana

#### Properties

The following properties are available in the `grafana_folder` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `permissions`

The permissions of the folder

#### Parameters

The following parameters are available in the `grafana_folder` type.

* [`grafana_api_path`](#-grafana_folder--grafana_api_path)
* [`grafana_password`](#-grafana_folder--grafana_password)
* [`grafana_url`](#-grafana_folder--grafana_url)
* [`grafana_user`](#-grafana_folder--grafana_user)
* [`organization`](#-grafana_folder--organization)
* [`provider`](#-grafana_folder--provider)
* [`title`](#-grafana_folder--title)
* [`uid`](#-grafana_folder--uid)

##### <a name="-grafana_folder--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_folder--grafana_password"></a>`grafana_password`

The password for the Grafana server (optional)

##### <a name="-grafana_folder--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_folder--grafana_user"></a>`grafana_user`

The username for the Grafana server (optional)

##### <a name="-grafana_folder--organization"></a>`organization`

The organization name to create the folder on

Default value: `1`

##### <a name="-grafana_folder--provider"></a>`provider`

The specific backend to use for this `grafana_folder` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-grafana_folder--title"></a>`title`

The title of the folder

##### <a name="-grafana_folder--uid"></a>`uid`

UID of the folder

### <a name="grafana_ldap_config"></a>`grafana_ldap_config`

Manage Grafana LDAP configuration

#### Parameters

The following parameters are available in the `grafana_ldap_config` type.

* [`backup`](#-grafana_ldap_config--backup)
* [`group`](#-grafana_ldap_config--group)
* [`mode`](#-grafana_ldap_config--mode)
* [`owner`](#-grafana_ldap_config--owner)
* [`replace`](#-grafana_ldap_config--replace)
* [`title`](#-grafana_ldap_config--title)
* [`validate_cmd`](#-grafana_ldap_config--validate_cmd)

##### <a name="-grafana_ldap_config--backup"></a>`backup`

Valid values: `true`, `false`, `yes`, `no`

Backup existing files before replacing them into the file-bucket

Default value: `false`

##### <a name="-grafana_ldap_config--group"></a>`group`

Group of the LDAP configuration file either as String or Integer (default: grafana)

Default value: `grafana`

##### <a name="-grafana_ldap_config--mode"></a>`mode`

File-permissions mode of the LDAP configuration file as String

Default value: `0440`

##### <a name="-grafana_ldap_config--owner"></a>`owner`

Owner of the LDAP configuration-file either as String or Integer (default: root)

Default value: `root`

##### <a name="-grafana_ldap_config--replace"></a>`replace`

Valid values: `true`, `false`, `yes`, `no`

Replace existing files

Default value: `true`

##### <a name="-grafana_ldap_config--title"></a>`title`

Path to ldap.toml

##### <a name="-grafana_ldap_config--validate_cmd"></a>`validate_cmd`

A command to validate the new Grafana LDAP configuration before actually replacing it

### <a name="grafana_ldap_group_mapping"></a>`grafana_ldap_group_mapping`

Map an LDAP group to a Grafana role.

#### Parameters

The following parameters are available in the `grafana_ldap_group_mapping` type.

* [`grafana_admin`](#-grafana_ldap_group_mapping--grafana_admin)
* [`group_dn`](#-grafana_ldap_group_mapping--group_dn)
* [`ldap_server_name`](#-grafana_ldap_group_mapping--ldap_server_name)
* [`org_role`](#-grafana_ldap_group_mapping--org_role)
* [`title`](#-grafana_ldap_group_mapping--title)

##### <a name="-grafana_ldap_group_mapping--grafana_admin"></a>`grafana_admin`

Valid values: `true`, `false`, `yes`, `no`

Additonal flag for Grafana > v5.3 to signal admin-role to Grafana

Default value: `false`

##### <a name="-grafana_ldap_group_mapping--group_dn"></a>`group_dn`

The LDAP distinguished-name of the group

##### <a name="-grafana_ldap_group_mapping--ldap_server_name"></a>`ldap_server_name`

The LDAP server config to apply the group-mappings on

##### <a name="-grafana_ldap_group_mapping--org_role"></a>`org_role`

Valid values: `Admin`, `Editor`, `Viewer`

The Grafana role the shall be assigned to this group

##### <a name="-grafana_ldap_group_mapping--title"></a>`title`

A unique identifier of the resource

### <a name="grafana_ldap_server"></a>`grafana_ldap_server`

Manage Grafana LDAP servers for LDAP authentication.

#### Parameters

The following parameters are available in the `grafana_ldap_server` type.

* [`attributes`](#-grafana_ldap_server--attributes)
* [`bind_dn`](#-grafana_ldap_server--bind_dn)
* [`bind_password`](#-grafana_ldap_server--bind_password)
* [`client_cert`](#-grafana_ldap_server--client_cert)
* [`client_key`](#-grafana_ldap_server--client_key)
* [`group_search_base_dns`](#-grafana_ldap_server--group_search_base_dns)
* [`group_search_filter`](#-grafana_ldap_server--group_search_filter)
* [`group_search_filter_user_attribute`](#-grafana_ldap_server--group_search_filter_user_attribute)
* [`hosts`](#-grafana_ldap_server--hosts)
* [`port`](#-grafana_ldap_server--port)
* [`root_ca_cert`](#-grafana_ldap_server--root_ca_cert)
* [`search_base_dns`](#-grafana_ldap_server--search_base_dns)
* [`search_filter`](#-grafana_ldap_server--search_filter)
* [`ssl_skip_verify`](#-grafana_ldap_server--ssl_skip_verify)
* [`start_tls`](#-grafana_ldap_server--start_tls)
* [`title`](#-grafana_ldap_server--title)
* [`use_ssl`](#-grafana_ldap_server--use_ssl)

##### <a name="-grafana_ldap_server--attributes"></a>`attributes`

Mapping LDAP attributes to their Grafana user-account-properties (optional)

##### <a name="-grafana_ldap_server--bind_dn"></a>`bind_dn`

If the LDAP server requires authentication (i.e. non-anonymous), provide the distinguished-name (dn) here (optional)

##### <a name="-grafana_ldap_server--bind_password"></a>`bind_password`

If the LDAP server requires authentication (i.e. non-anonymous), provide the password (optional)

##### <a name="-grafana_ldap_server--client_cert"></a>`client_cert`

If the LDAP server requires certificate-based authentication, specify the client's certificate (for TLS and SSL,
optional)

##### <a name="-grafana_ldap_server--client_key"></a>`client_key`

If the LDAP server requires certificate-based authentication, specify the client's certificate (for TLS and SSL,
optional)

##### <a name="-grafana_ldap_server--group_search_base_dns"></a>`group_search_base_dns`

The base-dn to be used when querying LDAP for group-accounts (optional)

##### <a name="-grafana_ldap_server--group_search_filter"></a>`group_search_filter`

A search-filter to be used when querying LDAP for group-accounts (optional)

##### <a name="-grafana_ldap_server--group_search_filter_user_attribute"></a>`group_search_filter_user_attribute`

The attribute to be used to locate matching user-accounts in the group (optional)

##### <a name="-grafana_ldap_server--hosts"></a>`hosts`

The servers to perform LDAP authentication at

##### <a name="-grafana_ldap_server--port"></a>`port`

The port to connect at the LDAP servers (389 for TLS/plaintext, 636 for SSL [ldaps], optional)

Default value: `389`

##### <a name="-grafana_ldap_server--root_ca_cert"></a>`root_ca_cert`

The root ca-certificate to verify the LDAP server's SSL certificate against (for TLS and SSL, optional)

Default value: `/etc/ssl/certs/ca-certificates.crt`

##### <a name="-grafana_ldap_server--search_base_dns"></a>`search_base_dns`

The one or more base-dn to be used when querying LDAP for user-accounts (optional)

Default value: `[]`

##### <a name="-grafana_ldap_server--search_filter"></a>`search_filter`

A search-filter to be used when querying LDAP for user-accounts (optional)

##### <a name="-grafana_ldap_server--ssl_skip_verify"></a>`ssl_skip_verify`

Valid values: `true`, `false`, `yes`, `no`

Set to true to disable verification of the LDAP server's SSL certificate (for TLS and SSL, optional)

Default value: `false`

##### <a name="-grafana_ldap_server--start_tls"></a>`start_tls`

Valid values: `true`, `false`, `yes`, `no`

Set to true if you want to perform LDAP via a TLS-connection (not meant to be for SSL, optional)

Default value: `true`

##### <a name="-grafana_ldap_server--title"></a>`title`

A unique identified for this LDAP server.

##### <a name="-grafana_ldap_server--use_ssl"></a>`use_ssl`

Valid values: `true`, `false`, `yes`, `no`

Set to true if you want to perform LDAP via a SSL-connection (not meant to be for TLS, optional)

Default value: `false`

### <a name="grafana_membership"></a>`grafana_membership`

Manage resource memberships in Grafana

#### Properties

The following properties are available in the `grafana_membership` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `role`

Valid values: `Admin`, `Editor`, `Viewer`

The role to apply to the membership (Admin, Editor, Viewer)

#### Parameters

The following parameters are available in the `grafana_membership` type.

* [`grafana_api_path`](#-grafana_membership--grafana_api_path)
* [`grafana_password`](#-grafana_membership--grafana_password)
* [`grafana_url`](#-grafana_membership--grafana_url)
* [`grafana_user`](#-grafana_membership--grafana_user)
* [`membership_type`](#-grafana_membership--membership_type)
* [`name`](#-grafana_membership--name)
* [`organization`](#-grafana_membership--organization)
* [`provider`](#-grafana_membership--provider)
* [`target_name`](#-grafana_membership--target_name)
* [`user_name`](#-grafana_membership--user_name)

##### <a name="-grafana_membership--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_membership--grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="-grafana_membership--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_membership--grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="-grafana_membership--membership_type"></a>`membership_type`

Valid values: `organization`, `team`

The underlying type of the membership (organization, team)

##### <a name="-grafana_membership--name"></a>`name`

namevar

The name of the membership.

##### <a name="-grafana_membership--organization"></a>`organization`

The name of the organization to add membership for (team only)

Default value: `Main Org.`

##### <a name="-grafana_membership--provider"></a>`provider`

The specific backend to use for this `grafana_membership` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-grafana_membership--target_name"></a>`target_name`

The name of the target to add membership for

##### <a name="-grafana_membership--user_name"></a>`user_name`

The name of the user to add membership for

### <a name="grafana_notification"></a>`grafana_notification`

Manage notification in Grafana

#### Properties

The following properties are available in the `grafana_notification` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `frequency`

The notification reminder frequency

##### `is_default`

Valid values: `true`, `false`

Whether the notification is the default one

Default value: `false`

##### `send_reminder`

Valid values: `true`, `false`

Whether automatic message resending is enabled or not

Default value: `false`

##### `settings`

Additional JSON data to configure the notification

##### `type`

The notification type

#### Parameters

The following parameters are available in the `grafana_notification` type.

* [`grafana_api_path`](#-grafana_notification--grafana_api_path)
* [`grafana_password`](#-grafana_notification--grafana_password)
* [`grafana_url`](#-grafana_notification--grafana_url)
* [`grafana_user`](#-grafana_notification--grafana_user)
* [`name`](#-grafana_notification--name)
* [`provider`](#-grafana_notification--provider)

##### <a name="-grafana_notification--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_notification--grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="-grafana_notification--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_notification--grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="-grafana_notification--name"></a>`name`

namevar

The name of the notification.

##### <a name="-grafana_notification--provider"></a>`provider`

The specific backend to use for this `grafana_notification` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="grafana_organization"></a>`grafana_organization`

Manage organizations in Grafana

#### Properties

The following properties are available in the `grafana_organization` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `grafana_organization` type.

* [`grafana_api_path`](#-grafana_organization--grafana_api_path)
* [`grafana_password`](#-grafana_organization--grafana_password)
* [`grafana_url`](#-grafana_organization--grafana_url)
* [`grafana_user`](#-grafana_organization--grafana_user)
* [`name`](#-grafana_organization--name)
* [`provider`](#-grafana_organization--provider)

##### <a name="-grafana_organization--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_organization--grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="-grafana_organization--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_organization--grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="-grafana_organization--name"></a>`name`

namevar

The name of the organization.

##### <a name="-grafana_organization--provider"></a>`provider`

The specific backend to use for this `grafana_organization` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="grafana_plugin"></a>`grafana_plugin`

manages grafana plugins

#### Examples

##### Install a grafana plugin

```puppet
grafana_plugin { 'grafana-simple-json-datasource': }
```

##### Install a grafana plugin from different repo

```puppet
grafana_plugin { 'grafana-simple-json-datasource':
  ensure => 'present',
  repo   => 'https://nexus.company.com/grafana/plugins',
}
```

##### Install a grafana plugin from a plugin url

```puppet
grafana_plugin { 'grafana-example-custom-plugin':
  ensure     => 'present',
  plugin_url => 'https://github.com/example/example-custom-plugin/zipball/v1.0.0'
}
```

##### Uninstall a grafana plugin

```puppet
grafana_plugin { 'grafana-simple-json-datasource':
  ensure => 'absent',
}
```

##### Show resources

```puppet
$ puppet resource grafana_plugin
```

#### Properties

The following properties are available in the `grafana_plugin` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `grafana_plugin` type.

* [`name`](#-grafana_plugin--name)
* [`plugin_url`](#-grafana_plugin--plugin_url)
* [`provider`](#-grafana_plugin--provider)
* [`repo`](#-grafana_plugin--repo)

##### <a name="-grafana_plugin--name"></a>`name`

Valid values: `%r{^\S+$}`

namevar

The name of the plugin to enable

##### <a name="-grafana_plugin--plugin_url"></a>`plugin_url`

Full url to the plugin zip file

##### <a name="-grafana_plugin--provider"></a>`provider`

The specific backend to use for this `grafana_plugin` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-grafana_plugin--repo"></a>`repo`

The URL of an internal plugin server

### <a name="grafana_team"></a>`grafana_team`

Manage teams in Grafana

#### Properties

The following properties are available in the `grafana_team` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `home_dashboard`

The id or name of the home dashboard

Default value: `Default`

##### `home_dashboard_folder`

The UID or name of the home dashboard folder

##### `theme`

The theme to use for the team

##### `timezone`

The timezone to use for the team

#### Parameters

The following parameters are available in the `grafana_team` type.

* [`email`](#-grafana_team--email)
* [`grafana_api_path`](#-grafana_team--grafana_api_path)
* [`grafana_password`](#-grafana_team--grafana_password)
* [`grafana_url`](#-grafana_team--grafana_url)
* [`grafana_user`](#-grafana_team--grafana_user)
* [`name`](#-grafana_team--name)
* [`organization`](#-grafana_team--organization)
* [`provider`](#-grafana_team--provider)

##### <a name="-grafana_team--email"></a>`email`

The email for the team

Default value: `''`

##### <a name="-grafana_team--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_team--grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="-grafana_team--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_team--grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="-grafana_team--name"></a>`name`

namevar

The name of the team

##### <a name="-grafana_team--organization"></a>`organization`

The organization the team belongs to

Default value: `Main Org.`

##### <a name="-grafana_team--provider"></a>`provider`

The specific backend to use for this `grafana_team` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="grafana_user"></a>`grafana_user`

Manage users in Grafana

#### Properties

The following properties are available in the `grafana_user` type.

##### `email`

The email for the user

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `full_name`

The full name of the user.

##### `is_admin`

Valid values: `true`, `false`

Whether the user is a grafana admin

##### `organizations`

A hash of organizations and roles

##### `password`

The password for the user

##### `theme`

The theme for the user

#### Parameters

The following parameters are available in the `grafana_user` type.

* [`grafana_api_path`](#-grafana_user--grafana_api_path)
* [`grafana_password`](#-grafana_user--grafana_password)
* [`grafana_url`](#-grafana_user--grafana_url)
* [`grafana_user`](#-grafana_user--grafana_user)
* [`name`](#-grafana_user--name)
* [`provider`](#-grafana_user--provider)

##### <a name="-grafana_user--grafana_api_path"></a>`grafana_api_path`

The absolute path to the API endpoint

Default value: `/api`

##### <a name="-grafana_user--grafana_password"></a>`grafana_password`

The password for the Grafana server

##### <a name="-grafana_user--grafana_url"></a>`grafana_url`

The URL of the Grafana server

Default value: `''`

##### <a name="-grafana_user--grafana_user"></a>`grafana_user`

The username for the Grafana server

##### <a name="-grafana_user--name"></a>`name`

namevar

The username of the user.

##### <a name="-grafana_user--provider"></a>`provider`

The specific backend to use for this `grafana_user` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Functions

### <a name="grafana--deep_find_and_remove"></a>`grafana::deep_find_and_remove`

Type: Ruby 4.x API

== Function: deep_find_and_remove

This function takes a hash as input, along with a string
(key). Additionally, the optional removekey (defaults to
'puppetsource') is a parameter.

The purpose of this function is to extract the 'options' subhash
from the array of hashes given to provision dashboards. This options
subhash may contain a path and source which puppet will use for
provisioning: creating the path and applying the files from the
source.

Additionally, if the key 'puppetsource' exists in the sub-hash, it
will be deleted from the structure. Thus the output of this function
may be used in yaml format for grafana's provisioning
configuration file for dashboards.

#### `grafana::deep_find_and_remove(String $key, Hash $object, Optional[String] $removekey)`

== Function: deep_find_and_remove

This function takes a hash as input, along with a string
(key). Additionally, the optional removekey (defaults to
'puppetsource') is a parameter.

The purpose of this function is to extract the 'options' subhash
from the array of hashes given to provision dashboards. This options
subhash may contain a path and source which puppet will use for
provisioning: creating the path and applying the files from the
source.

Additionally, if the key 'puppetsource' exists in the sub-hash, it
will be deleted from the structure. Thus the output of this function
may be used in yaml format for grafana's provisioning
configuration file for dashboards.

Returns: `Array`

##### `key`

Data type: `String`



##### `object`

Data type: `Hash`



##### `removekey`

Data type: `Optional[String]`



### <a name="grafana--get_sub_paths"></a>`grafana::get_sub_paths`

Type: Ruby 4.x API

== Function get_sub_paths

This function receives an input path as an input parameter, and
returns an array of the subpaths in the input, excluding the input
path itself. The function will attempt to ignore any extra slashes
in the path given.

This function will only work on UNIX paths with forward slashes (/).

Examples:
input = '/var/lib/grafana/dashboards'
output = [ '/var', '/var/lib', '/var/lib/grafana'/ ]

input = '/opt'
output = []

input = '/first/second/'
output = [ '/first' ]

#### `grafana::get_sub_paths(String $inputpath)`

== Function get_sub_paths

This function receives an input path as an input parameter, and
returns an array of the subpaths in the input, excluding the input
path itself. The function will attempt to ignore any extra slashes
in the path given.

This function will only work on UNIX paths with forward slashes (/).

Examples:
input = '/var/lib/grafana/dashboards'
output = [ '/var', '/var/lib', '/var/lib/grafana'/ ]

input = '/opt'
output = []

input = '/first/second/'
output = [ '/first' ]

Returns: `Array`

##### `inputpath`

Data type: `String`



## Tasks

### <a name="change_grafana_admin_password"></a>`change_grafana_admin_password`

Change the Grafana admin user's password

**Supports noop?** false

#### Parameters

##### `old_password`

Data type: `Optional[String[1]]`

The old admin password

##### `new_password`

Data type: `Optional[String[1]]`

The new admin password

##### `uri`

Data type: `Enum['http','https']`

http or https

##### `port`

Data type: `Integer`

The port Grafana is running on

