# install cli
class space_cli(
  Hash[String,Hash] $packages = {},
  Hash[String,Hash] $files    = {},
  Optional[Boolean] $ensure   = true,
  Hash              $config,
  Boolean           $sentry    = false,
  Optional[String]  $sentrydsn = undef,
) {

  create_resources(package, $packages)

  $file_defaults = {
     owner => 0,
     group => 0,
     mode  => '0755',
  }

  create_resources(file, $files, $file_defaults)

  if $ensure == true {
    if $::cli_exists {
      $bash_source='.bashrc'
    } else {
      $bash_source='.bashrc_no_cli'
    }
  } else {
      $bash_source='.bashrc_no_cli'
  }

  file { "/root/.bashrc":
    source  => [ "puppet:///modules/${module_name}/${bash_source}" ],
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
  }

  file { "/root/.bash_profile":
    ensure => 'link',
    target => '/root/.bashrc'
  }


  file_line { "Streebog 1":
    path  => '/etc/login.defs',
    line  => 'ENCRYPT_METHOD GOST_YESCRYPT',
    match => '^ENCRYPT_METHOD',
  }
  file_line { "Streebog 2":
    path  => '/etc/pam.d/common-password',
    line  => 'password        [success=1 default=ignore]      pam_unix.so obscure gost-yescrypt',
    match => '^password.*pam_unix.so',
  }
  service { 'console-setup.service':
    enable   => true,
    ensure   => running,
    provider => systemd
  }
  file { '/etc/default/keyboard':
    ensure => present,
    source => [ "puppet:///modules/${module_name}/keyboard" ],
    mode   => '0644',
    owner  => 'root',
    notify => Service['console-setup.service'],
  }
  file { '/etc/default/console-setup':
    ensure => present,
    source => [ "puppet:///modules/${module_name}/console-setup" ],
    mode   => '0644',
    owner  => 'root',
    notify => Service['console-setup.service'],
  }

  file { '/etc/veil/cli/config.json':
    ensure  => file,
    content => template("${module_name}/config.json.erb"),
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
  }

  if $sentry {
    $sentry_config_ensure = "present"
  } else {
    $sentry_config_ensure = "absent"
  }

  file { "/etc/veil/sentry/cli.json":
    ensure  => $sentry_config_ensure,
    mode    => '0644',
    owner   => 0,
    group   => 0,
    content => template("$module_name/sentry-cli.json.erb"),
  }

}
