# configure environment to install controller from .deb and dev repo
class space_node::init_services {

  $veil_ulogd2_ensure = lookup('space_node::ulogd2_ensure')
  $veil_linstor_ensure = lookup('space_node::linstor_ensure')
  $veil_numad_ensure = lookup('space_node::numad_ensure')

  $veil_pgsql_db_user = lookup('veil_pgsql_db_user')
  $veil_pgsql_db_name = lookup('veil_pgsql_node_db_name')
  $veil_pgsql_port = lookup('veil_pgsql_port')
  $veil_pgbouncer_port = lookup('veil_pgbouncer_port')
  $pgsql_db_password = lookup('pgsql_db_password')
  $veil_node_user = lookup('veil_node_user')
  $veil_global_group = hiera('veil_global_group')
  $redis_db_password = lookup('redis_db_password')
  $veil_pgsql_node_db_name = lookup('veil_pgsql_node_db_name')

  file { "/var/log/veil/node/settings_local.py":
    ensure  => present,
    content => template("$module_name/settings_local.py.erb"),
  }

#  exec { 'node_obfuscate':
#    command => "/var/lib/ecp-veil/node/env/bin/pyarmor obfuscate --exact /var/log/veil/node/settings_local.py --output /var/lib/ecp-veil/node/bazalt --bootstrap 3",
#    onlyif  => "test -f /var/log/veil/node/settings_local.py",
#  }

  file { "/var/lib/ecp-veil/node/bazalt/settings_local.py":
    ensure  => present,
    mode    => '0644',
    owner => $veil_node_user,
    group => $veil_global_group,
  }


    file { "/lib/systemd/system/veil-route.service":
    source  => [
            "puppet:///modules/${module_name}/veil-route.service",
    ],
    owner => 'root',
    group => 'root',
    mode  => '0644',
  }
  service { 'veil-route.service':
    enable   => true,
    provider => systemd,
  }
  
  file { "/lib/systemd/system/node_supervisor.service":
    source  => [
            "puppet:///modules/${module_name}/node_supervisor.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
 file { "/lib/systemd/system/veil-mdev-recreate.service":
    source  => [
            "puppet:///modules/${module_name}/veil-mdev-recreate.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
   file { "/lib/systemd/system/veil-watchdog.service":
    source  => [
            "puppet:///modules/${module_name}/veil-watchdog.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  file { "/lib/systemd/system/veil.slice":
    source => [
            "puppet:///modules/${module_name}/veil.slice",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  # open-iscsi+10sec > veil-zfs-import > zfs-import.target > zfs-zed, zfs-mount > glusterd
  # zfs крашится при отсутствии незаменимых дисков в пулах, которые д.б. импортированы
  Service { 'systemd-udev-settle.service':
    ensure => running,
    enable => true,
    provider => systemd,
  }
  Service { 'zfs-import-cache':
    ensure => stopped,
    enable => false,
    provider => systemd,
  }
  Service { 'veil-zfs-import':
    ensure => running,
    provider => systemd,
  }
  file { "/etc/init.d/zfs-zed":
    ensure => absent,
  }
  file { "/lib/systemd/system/zfs-zed.service":
    source => [
      "puppet:///modules/${module_name}/zfs-zed.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  ~> Service { 'zfs-zed':
    ensure => running,
    provider => systemd,
  }
  file { "/etc/systemd/system/zfs-mount.service":
    source => [
      "puppet:///modules/${module_name}/zfs-mount.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  ~> Service { 'zfs-mount':
    provider => systemd,
    ensure => running,
  }
  file { "/lib/systemd/system/glusterd.service":
    source => [
      "puppet:///modules/${module_name}/glusterd.service",
    ],
    owner => 'root',
    group => 'root',
    mode => '0644',
  }
  ~> Service { 'glusterd':
    ensure => running,
    provider => systemd,
  }
  file { "/lib/systemd/system/target.service":
    source => [ "puppet:///modules/${module_name}/target.service" ],
    owner => "root",
    group => "root",
    mode => "0644",
  }
  Service { "target.service":
    enable => true,
    provider => systemd,
  }
  # lldpad order loop is fixed in 18441
  Service { 'lldpad.service':
    ensure => running,
    enable => true,
    provider => systemd,
  }
  Service { 'lldpad.socket':
    ensure => running,
    enable => true,
    provider => systemd,
  }
  if defined('$::is_node_no_controller') {
    if $is_node_no_controller == "1" {
      file { "/lib/systemd/system/gunicorn-django-node.service":
        source => [
          "puppet:///modules/${module_name}/gunicorn-django-node.service",
        ],
        owner  => 'root',
        group  => 'root',
        mode   => '0644',
      }
      file { "/lib/systemd/system/websockify-node.service":
        source => [
          "puppet:///modules/${module_name}/websockify-node.service",
        ],
        owner  => 'root',
        group  => 'root',
        mode   => '0644',
      }
      file { "/lib/systemd/system/gunicorn-proxy-node.service":
        source => [
          "puppet:///modules/${module_name}/gunicorn-proxy-node.service",
        ],
        owner  => 'root',
        group  => 'root',
        mode   => '0644',
      }
      file { "/lib/systemd/system/gunicorn-uploader-node.service":
        source => [
          "puppet:///modules/${module_name}/gunicorn-uploader-node.service",
        ],
        owner  => 'root',
        group  => 'root',
        mode   => '0644',
      }
      service { 'gunicorn-django-node':
        ensure => 'running',
        enable => true,
      }
      service { 'gunicorn-proxy-node':
        ensure => 'running',
        enable => true,
      }
      service { 'gunicorn-uploader-node':
        ensure => 'running',
        enable => true,
      }
      service { 'websockify-node.service':
        enable => true,
        ensure => 'running',
      }
    } else {
      exec { 'stop_gunicorn-django-node':
        command => "systemctl stop gunicorn-django-node; systemctl disable gunicorn-django-node",
        onlyif  => "systemctl is-active gunicorn-django-node.service>/dev/null",
        path    =>  ["/usr/bin","/usr/sbin", "/bin"],
      }
      exec { 'stop_gunicorn-proxy-node':
        command => "systemctl stop gunicorn-proxy-node; systemctl disable gunicorn-proxy-node",
        onlyif  => "systemctl is-active gunicorn-proxy-node.service>/dev/null",
        path    =>  ["/usr/bin","/usr/sbin", "/bin"],
      }
      exec { 'stop_gunicorn-uploader-node':
        command => "systemctl stop gunicorn-uploader-node; systemctl disable gunicorn-uploader-node",
        onlyif  => "systemctl is-active gunicorn-uploader-node.service>/dev/null",
        path    =>  ["/usr/bin","/usr/sbin", "/bin"],
      }
      exec { 'stop_websockify-node':
        command => "systemctl stop websockify-node; systemctl disable websockify-node",
        onlyif  => "systemctl is-active websockify-node.service>/dev/null",
        path    =>  ["/usr/bin","/usr/sbin", "/bin"],
      }
    }
  }
#  if $veil_node::net_configured {
    service { 'node_supervisor.service':
      ensure => 'running',
      enable => true,
     provider => systemd,
    }
#  }
 service { 'lvm2-lvmetad.service':
    enable => false,
    ensure => false,
    provider => systemd,
  }
  service {'glusterd.service':
    ensure    => running,
    enable    => true,
    provider => systemd,
  }
  # service {'drbd.service':
  #   ensure    => $veil_linstor_ensure,
  #   enable    => $veil_linstor_ensure,
  # }
  service {'linstor-satellite':
    ensure    => $veil_linstor_ensure,
    enable    => $veil_linstor_ensure,
    provider => systemd,
  }
  service {'numad':
    ensure    => $veil_numad_ensure,
    enable    => $veil_numad_ensure,
    provider => systemd,
  }
  service {'veil-mdev-recreate.service':
    ensure => false,
    enable => true,
    provider => systemd,
  }
  service {'veil-watchdog.service':
    ensure => false,
    enable => true,
    provider => systemd,
  }
  service { 'nftables.service':
    enable => true,
    ensure => false,
    provider => systemd,
  }
  service { 'lxc-net.service':
    enable => mask,
    provider => systemd,
  }
  service { 'zfs-zed.service':
    enable => true,
    ensure => running,
    provider => systemd,
  }
  service { 'prometheus-node-exporter-ipmitool-sensor.timer':
    enable => false,
    ensure => false,
    provider => systemd,
  }
  service { 'ulogd2.service':
    enable => $veil_ulogd2_ensure,
    ensure => $veil_ulogd2_ensure,
    provider => systemd,
  }
  service { 'sbd_remote.service':
    # masking since it conflicts with sbd itself
    enable => mask,
    provider => systemd,
  }
  file { "/var/lib/ecp-veil/node/other/auth.py":
    source  => [
            "puppet:///modules/${module_name}/auth.py",
    ],
    mode => '0550',
  }

  # TEST4
  file { "/var/lib/ecp-veil/tests/node_init_test4.sh":
    ensure  => present,
    content => template("${module_name}/node_init_test4.sh.erb"),
    mode => '0550',
  }
  # TEST6
  file { "/var/lib/ecp-veil/tests/node_init_test6.sh":
    ensure  => present,
    content => template("${module_name}/node_init_test6.sh.erb"),
    mode => '0550',
  }
  # TEST7
  file { "/var/lib/ecp-veil/tests/node_init_test7.sh":
    ensure  => present,
    content => template("${module_name}/node_init_test7.sh.erb"),
    mode => '0550',
  }
  file { '/var/lib/ecp-veil/node/bin/mdev-recreate':
    ensure  => present,
    source  => [ "puppet:///modules/${module_name}/mdev-recreate" ],
    mode    => '0755',
  }
  file { '/var/lib/ecp-veil/node/local_data/slices-tune.conf':
    ensure  => present,
    source  => [ "puppet:///modules/${module_name}/slices-tune.conf" ],
    owner => 'veil-node',
    group => 'veil-admins',
    mode    => '0664',
  }
  file { '/var/lib/ecp-veil/node/bin/slices-tune.py':
    ensure  => present,
    source  => [ "puppet:///modules/${module_name}/slices-tune.py" ],
    mode    => '0755',
  }
}
