#!/bin/sh
color_subr="/usr/share/veil/color.subr"
system_subr="/usr/share/veil/system.subr"
deb_subr="/usr/share/veil/deb.subr"

set -e
. ${color_subr}
. ${system_subr}
. ${deb_subr}
set +e

IS_DHCP=0
IS_STATIC=0
# back compat
[ -z "${UTILS_CONFIG_DIR}" ] && UTILS_CONFIG_DIR="/var/lib/ecp-veil/utils/other"
[ -z "${BASE_DIR}" ] && BASE_DIR="/var/lib/ecp-veil"

collect_netinfo()
{
	IP=$( ${GREP_CMD} address /etc/network/interfaces | ${AWK_CMD} '{print $2}' )
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ip in collect_netinfo first_boot.sh - ${IP}${NORMAL}"
	GW=$( ${GREP_CMD} gateway /etc/network/interfaces | ${AWK_CMD} '{print $2}' )
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Gateway in collect_netinfo first_boot.sh - ${GW}${NORMAL}"
	NS=$( ${GREP_CMD} nameserver /etc/network/interfaces | ${AWK_CMD} '{$1=""; print $0}' | ${AWK_CMD} '{for(i=1;i<NF;i++)if(i!=NF){$i=$i","}}1' | ${SED_CMD} 's/ //g' )
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ns in collect_netinfo first_boot.sh - ${NS}${NORMAL}"
	MASK=$( ${GREP_CMD} netmask /etc/network/interfaces | ${AWK_CMD} '{print $2}' )
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Mask in collect_netinfo first_boot.sh - ${MASK}${NORMAL}"

	if $( echo ${IP} | ${GREP_CMD} -q '/' ); then
		IS_PREFIX=1
		MASK=
	else
		IS_PREFIX=0
		[ -z "${MASK}" ] && MASK="255.255.255.0"
	fi

	IFACE=$( ${IP_CMD} link | ${GREP_CMD} BROADCAST | ${GREP_CMD} -m 1 "state UP" | ${AWK_CMD} '{printf $2 " "}' | ${TR_CMD} -d : )
	if [ -n "${IFACE}" ]; then
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} First UP interface in collect_netinfo first_boot.sh - ${IFACE}${NORMAL}"
	else
		IFACE=$( get_default_uplink )
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} No UP interface! uplink interface ${IFACE} got by default${NORMAL}"
	fi

	VLANID=
	if [ -f "${BASE_DIR}/first_boot_vlan.conf" ]; then
		. ${BASE_DIR}/first_boot_vlan.conf
		rm ${BASE_DIR}/first_boot_vlan.conf
	fi

	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} VLANID in collect_netinfo first_boot.sh - ${VLANID}${NORMAL}"
}

LOG()
{
	echo "$*"
}

## MAIN
[ -r "${BASE_DIR}/tests/net_configured" ] && exit 0

if ${GREP_CMD} -E -q dhcp /etc/network/interfaces; then
	IS_DHCP=1
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} DHCP network config ${NORMAL}"
fi

if ${GREP_CMD} -E -q '([[:digit:]]{1,3}\.){3}[[:digit:]]{1,3}' /etc/network/interfaces; then
	IS_STATIC=1
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Static network config${NORMAL}"
fi

if [ "$IS_DHCP" -eq 0 -a "$IS_STATIC" -eq 0 ]; then
	IS_DHCP=1
fi

LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Start first boot ${NORMAL}"

# /tmp/nonet created by packer script
# i.e we work on vagrant
#if [ -f /tmp/nonet ]; then
#	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} /tmp/nonet exists, skip first boot${NORMAL}"
#	exit 0
#fi

# last octet is dynamic from Vagrantfile
HWADDR_ARGS=

VAGRANT_HWADDR=$( ${IP_CMD} a | ${GREP_CMD} 'link/ether' | ${GREP_CMD} 00:00:00:00:00: | ${HEAD_CMD} -n1 | ${AWK_CMD} '{printf $2}' )

if [ -n "${VAGRANT_HWADDR}" ]; then
	HWADDR_ARGS="-h ${VAGRANT_HWADDR}"
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Vagrant box mode: HWADDR_ARGS=${HWADDR_ARGS}${NORMAL}"
fi

collect_netinfo

VLAN_ARGS=
[ -n "${VLANID}" ] && VLAN_ARGS="-w ${VLANID}"

if [ "$IS_STATIC" -eq 1 ]; then
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Static - variable is ${IS_STATIC}${NORMAL}"

	if [ -z "$GW" ]; then
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Gateway is empty${NORMAL}"
		# exit 1
	else
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Gateway in first_boot.sh in static configuration - ${GW}. Date - ${DT}${NORMAL}"
	fi
	if [ -z "$IP" ]; then
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ip is empty${NORMAL}"
		exit 1
	else
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ip in first_boot.sh in static configuration - ${IP}. Date - ${DT}${NORMAL}"
	fi

	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Ip_prefix in first_boot.sh in static configuration - ${IS_PREFIX}. Date - ${DT}${NORMAL}"
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Mask in first_boot.sh in static configuration - ${MASK}. Date - ${DT}${NORMAL}"
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} Iface in first_boot.sh in static configuration - ${IFACE}. Date - ${DT}${NORMAL}"

	if [ ${IS_PREFIX} -eq 1 ]; then
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -f -m static -g ${GW} -i ${IP} -u ${IFACE} -t 3 ${VLAN_ARGS} ${HWADDR_ARGS}${NORMAL}"
		${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -f -m static -g ${GW} -i ${IP} -u ${IFACE} -t 3 -w ${VLANID} ${HWADDR_ARGS}
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} auto_configure_nic errcode: $?${NORMAL}"
	else
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -f -m static -g ${GW} -i ${IP} -s ${MASK} -u ${IFACE} -t 3 ${VLAN_ARGS} ${HWADDR_ARGS}${NORMAL}"
		${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -f -m static -g ${GW} -i ${IP} -s ${MASK} -u ${IFACE} -t 3 -w ${VLANID} ${HWADDR_ARGS}
		LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} auto_configure_nic errcode: $?${NORMAL}"
	fi
else
	LOG "* ${LCYAN}${MY_APPLICATION}: ${WHITE} ${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -m dhcp -u ${IFACE} -w ${VLANID} ${HWADDR_ARGS}${NORMAL}"
	${UTILS_CONFIG_DIR}/auto_configure_nic.sh -a init -m dhcp -u ${IFACE} ${VLAN_ARGS} ${HWADDR_ARGS}
fi

${TOUCH_CMD} "${BASE_DIR}/tests/net_configured"
exit 0
